import argparse
from .summary import Summary


class Tail(Summary):

    def __init__(self, **kwargs):
        Summary.__init__(self, **kwargs)
        self.cursor.execute(
            f"""
                SELECT COUNT(*) FROM "{self.file}"
            """
        )
        count = self.cursor.fetchone()[0]
        skip = count - self.lines
        self.cursor.execute(
            f"""
                SELECT * FROM "{self.file}" LIMIT ? OFFSET ?
            """, [self.lines, skip]
        )
        self.data = self.cursor.fetchall()


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        'file',
        help='The filename of the parquet file to show the last lines off.'
    )
    parser.add_argument(
        '-n',
        '--lines',
        default=10,
        type=int,
        help='Number of entries to show'
    )
    Tail(**vars(parser.parse_args())).print()


if __name__ == '__main__':
    main()



import duckdb


class Summary:

    def __init__(self, **kwargs):
        self.file = kwargs.get('file')
        self.lines = kwargs.get('lines')
        self.cursor = duckdb.connect().cursor()
        self.data = []

    def print(self):
        for entry in self.data:
            print(entry)



from setuptools import setup, find_packages

setup(
    name='pqt',
    version='0.0.1',
    description='Tools for quickly analyzing parquet content',
    author='Chris Kamphuis',
    author_email='mail@chriskamphuis.com',
    url='https://github.com/chriskamphuis/parquet-tools',
    install_requires=['duckdb'],
    packages=find_packages(),
    license='Apache License',
    entry_points={
        'console_scripts': [
            'pqt.head=pqt.head:main',
            'pqt.tail=pqt.tail:main'
        ]
    }
)
